import sys
from java.lang import System
from net.sf.l2j.gameserver.instancemanager import GrandBossManager
from net.sf.l2j.gameserver.lib import Rnd
from net.sf.l2j.gameserver.model.quest.jython import QuestJython as JQuest
from net.sf.l2j.gameserver.serverpackets import CreatureSay

# Boss: Core
CORE = 12052
MINIONS = [12054,12055,12058]

#Core Status Tracking :
DEAD = 1
ALIVE = 0

class Core(JQuest) :

    # init function. Add in here variables that you'd like to be inherited by subclasses (if any)
    def __init__(self,id,name,descr):
        JQuest.__init__(self,id,name,descr)
        self.FirstAttacked = False
        info = GrandBossManager.getInstance().getStatsSet(CORE)
        status = GrandBossManager.getInstance().getBossStatus(CORE)
        if status == DEAD :
            # load the respawn date and time for core from DB
            temp = long(info.getLong("respawn_time")) - System.currentTimeMillis()
            if temp > 0 :
                self.startQuestTimer("core_respawn", temp, None, None)
            else :
                # the time has already expired while the server was offline. Immediately spawn core in his room.
                core = self.addSpawn(CORE,17726,108915,-6480,0,False,0)
                GrandBossManager.getInstance().setBossStatus(CORE,ALIVE)
                GrandBossManager.getInstance().addBoss(core)
        else :
            loc_x = info.getInteger("loc_x")
            loc_y = info.getInteger("loc_y")
            loc_z = info.getInteger("loc_z")
            heading = info.getInteger("heading")
            hp = info.getInteger("currentHP")
            mp = info.getInteger("currentMP")
            core = self.addSpawn(CORE,loc_x,loc_y,loc_z,heading,False,0)
            GrandBossManager.getInstance().addBoss(core)
            core.setCurrentHpMp(hp,mp)

    def onAdvEvent (self,event,npc,player):
        if event == "core_respawn" :
            core = self.addSpawn(CORE,17726,108915,-6480,0,False,0)
            GrandBossManager.getInstance().setBossStatus(CORE,ALIVE)
            GrandBossManager.getInstance().addBoss(core)
        return

    def onAttack (self,npc,player,damage,isPet):
        objId=npc.getObjectId()
        if self.FirstAttacked:
           if Rnd.get(100) : return
           npc.broadcastPacket(CreatureSay(objId,0,npc.getName(),"Removing intruders."))
        else :
           self.FirstAttacked = True
           npc.broadcastPacket(CreatureSay(objId,0,npc.getName(),"A non-permitted target has been discovered."))
           npc.broadcastPacket(CreatureSay(objId,0,npc.getName(),"Starting intruder removal system."))
        return 

    def onKill(self,npc,player,isPet):
        npcId = npc.getNpcId()
        if npcId == CORE:
            objId=npc.getObjectId()
            npc.broadcastPacket(CreatureSay(objId,0,npc.getName(),"A fatal error has occurred."))
            npc.broadcastPacket(CreatureSay(objId,0,npc.getName(),"System is being shut down..."))
            npc.broadcastPacket(CreatureSay(objId,0,npc.getName(),"......"))
            self.FirstAttacked = False
            GrandBossManager.getInstance().setBossStatus(CORE,DEAD)
            respawnTime = long((27 + Rnd.get(47)) * 3600000)
            self.startQuestTimer("core_respawn", respawnTime, None, None)
            # also save the respawn time so that the info is maintained past reboots
            info = GrandBossManager.getInstance().getStatsSet(CORE)
            info.set("respawn_time",(long(System.currentTimeMillis()) + respawnTime))
            GrandBossManager.getInstance().setStatsSet(CORE,info)
        elif self.FirstAttacked :
            self.addSpawn(npcId,17726,108915,-6480,npc.getHeading(),True,0)
        return 

# now call the constructor (starts up the ai)
QUEST		= Core(-1,"core","ai")

QUEST.addKillId(CORE)
QUEST.addAttackId(CORE)

for minion in MINIONS :
    QUEST.addKillId(minion)