# Valakas AI script

import sys
import math
from java.lang import System
from net.sf.l2j.gameserver.instancemanager import GrandBossManager
from net.sf.l2j.gameserver.lib import Rnd
from net.sf.l2j.gameserver.model.quest.jython import QuestJython as JQuest
from net.sf.l2j.gameserver.serverpackets import Earthquake
from net.sf.l2j.gameserver.serverpackets import SocialAction
from net.sf.l2j.gameserver.serverpackets import SpecialCamera

VALAKAS = 12899

#Valakas status tracking
DORMANT = 0   # Valakas is spawned and no one has entered yet. Entry is unlocked
WAITING = 1   # Valakas is spawned and someone has entered, triggering a 30 minute window for additional people to enter
FIGHTING = 2  # Valakas is engaged in battle, annihilating his foes. Entry is locked
DEAD = 3      # Valakas has been killed. Entry is locked

class Valakas (JQuest):

  def __init__(self,id,name,descr):
    JQuest.__init__(self,id,name,descr)
    # initialize
    self.lastAttackVsValakasTime = 0
    self.valakasZone = GrandBossManager.getInstance().getZone(212852,-114842,-1632)
    info = GrandBossManager.getInstance().getStatsSet(VALAKAS)
    status = GrandBossManager.getInstance().getBossStatus(VALAKAS)
    if status == DEAD :    
      # load the unlock date and time for baium from DB
      temp = long(info.getLong("respawn_time")) - System.currentTimeMillis()
      if temp > 0 :
        # the unlock time has not yet expired.  Mark Valakas as currently locked (dead).  Setup a timer
        # to fire at the correct time (calculate the time between now and the unlock time,
        # setup a timer to fire after that many msec)
        self.startQuestTimer("valakas_unlock", temp, None, None)
      else :
        # the time has already expired while the server was offline.
        # the status needs to be changed to DORMANT
        GrandBossManager.getInstance().setBossStatus(VALAKAS,DORMANT)
    elif status == FIGHTING :
      loc_x = info.getInteger("loc_x")
      loc_y = info.getInteger("loc_y")
      loc_z = info.getInteger("loc_z")
      heading = info.getInteger("heading")
      hp = info.getInteger("currentHP")
      mp = info.getInteger("currentMP")
      valakas = self.addSpawn(VALAKAS,loc_x,loc_y,loc_z,heading,False,0)
      GrandBossManager.getInstance().addBoss(valakas)
      valakas.setCurrentHpMp(hp,mp)
      self.lastAttackVsValakasTime = System.currentTimeMillis()
      self.startQuestTimer("valakas_despawn",60000, valakas, None, True)
    elif status == WAITING :
      self.startQuestTimer("waiting",1800000, None, None)
    return

  def onAdvEvent (self,event,npc,player):
    if event == "waiting" :
      valakas = self.addSpawn(VALAKAS,212852,-114842,-1632,0,False,0)
      valakas.broadcastPacket(SocialAction(valakas.getObjectId(),3))
      valakas.broadcastPacket(Earthquake(valakas.getX(), valakas.getY(), valakas.getZ(), 20, 10))
      GrandBossManager.getInstance().addBoss(valakas)
      self.startQuestTimer("camera_1",2000, valakas, None)
    elif event == "camera_1" :
      self.startQuestTimer("camera_2",1500, npc, None)
      npc.broadcastPacket(SpecialCamera(npc.getObjectId(),1300,180,-5,3000,15000,0,-5,1,0))
    elif event == "camera_2" :
      self.startQuestTimer("camera_3",3300, npc, None)
      npc.broadcastPacket(SpecialCamera(npc.getObjectId(),500,180,-8,600,15000,0,60,1,0))
    elif event == "camera_3" :
      self.startQuestTimer("camera_4",2900, npc, None)
      npc.broadcastPacket(SpecialCamera(npc.getObjectId(),800,180,-8,2700,15000,0,30,1,0))
    elif event == "camera_4" :
      self.startQuestTimer("camera_5",2700, npc, None)
      npc.broadcastPacket(SpecialCamera(npc.getObjectId(),200,250,70,0,15000,30,80,1,0))
    elif event == "camera_5" :
      self.startQuestTimer("camera_6",1, npc, None)
      npc.broadcastPacket(SpecialCamera(npc.getObjectId(),1100,250,70,2500,15000,30,80,1,0))
    elif event == "camera_6" :
      self.startQuestTimer("camera_7",3200, npc, None)
      npc.broadcastPacket(SpecialCamera(npc.getObjectId(),700,150,30,0,15000,-10,60,1,0))
    elif event == "camera_7" :
      self.startQuestTimer("camera_8",1400, npc, None)
      npc.broadcastPacket(SpecialCamera(npc.getObjectId(),1200,150,20,2900,15000,-10,30,1,0))
    elif event == "camera_8" :
      self.startQuestTimer("camera_9",6700, npc, None)
      npc.broadcastPacket(SpecialCamera(npc.getObjectId(),750,170,15,3400,15000,10,-15,1,0))
    elif event == "camera_9" :
      self.startQuestTimer("valakas_fight",5700, npc, None)
      npc.broadcastPacket(SpecialCamera(npc.getObjectId(),750,170,-10,3400,15000,4000,-15,1,0))
    elif event == "valakas_fight" :
      GrandBossManager.getInstance().setBossStatus(VALAKAS,FIGHTING)
      self.startQuestTimer("valakas_despawn",60000, npc, None, True)
      self.lastAttackVsValakasTime = System.currentTimeMillis()
    elif event == "valakas_despawn" :
      # just in case the zone reference has been lost (somehow...), restore the reference
      if not self.valakasZone :
         self.valakasZone = GrandBossManager.getInstance().getZone(212852,-114842,-1632)
      if (self.lastAttackVsValakasTime + 1800000 < System.currentTimeMillis()) :
         npc.deleteMe()   # despawn the live-baium
         GrandBossManager.getInstance().setBossStatus(VALAKAS,DORMANT)
         self.valakasZone.oustAllPlayers()
         self.cancelQuestTimer("valakas_despawn", npc, None)
    elif event == "spawn_cubes" :
      self.addSpawn(8759,212852,-114842,-1632,0,False,900000)
      radius = 1500
      for i in range(0,19,1) :
        x = radius*math.cos(i*.331)
        y = radius*math.sin(i*.331)
        self.addSpawn(8759,212852 + int(x),-114842 + int(y),-1632,0,False,900000)
      self.cancelQuestTimer("valakas_despawn", npc, None)
      self.startQuestTimer("remove_players",900000, None, None)
    elif event == "remove_players" :
      self.valakasZone.oustAllPlayers()
    elif event == "valakas_unlock" :
      GrandBossManager.getInstance().setBossStatus(VALAKAS,DORMANT)
    return

  def onAttack(self, npc, player, damage, isPet) :
    # update a variable with the last action against valakas
    self.lastAttackVsValakasTime = System.currentTimeMillis()

  def onKill(self,npc,player,isPet):
    self.startQuestTimer("spawn_cubes", 10000, npc, None)
    respawnTime = long((192 + Rnd.get(145)) * 3600000)
    GrandBossManager.getInstance().setBossStatus(VALAKAS,DEAD)
    self.startQuestTimer("valakas_unlock", respawnTime, None, None)
    # also save the respawn time so that the info is maintained past reboots
    info = GrandBossManager.getInstance().getStatsSet(VALAKAS)
    info.set("respawn_time",(long(System.currentTimeMillis()) + respawnTime))
    GrandBossManager.getInstance().setStatsSet(VALAKAS,info)

# Quest class and state definition
QUEST       = Valakas(-1, "valakas", "ai")

QUEST.addKillId(VALAKAS)
QUEST.addAttackId(VALAKAS)