import sys
from java.lang import System
from net.sf.l2j.gameserver.instancemanager import GrandBossManager
from net.sf.l2j.gameserver.lib import Rnd
from net.sf.l2j.gameserver.model.quest.jython import QuestJython as JQuest

# Boss: Zaken
ZAKEN = 12374

#Zaken Status Tracking :
DEAD = 1
ALIVE = 0

class Zaken(JQuest) :

    # init function. Add in here variables that you'd like to be inherited by subclasses (if any)
    def __init__(self,id,name,descr):
        JQuest.__init__(self,id,name,descr)
        info = GrandBossManager.getInstance().getStatsSet(ZAKEN)
        status = GrandBossManager.getInstance().getBossStatus(ZAKEN)
        if status == DEAD :
            # load the respawn date and time for zaken from DB
            temp = long(info.getLong("respawn_time")) - System.currentTimeMillis()
            if temp > 0 :
                self.startQuestTimer("zaken_respawn", temp, None, None)
            else :
                # the time has already expired while the server was offline. Immediately spawn zaken in his ship.
                zaken = self.addSpawn(ZAKEN,55312,219168,-3223,0,False,0)
                GrandBossManager.getInstance().setBossStatus(ZAKEN,ALIVE)
                GrandBossManager.getInstance().addBoss(zaken)
        else :
            loc_x = info.getInteger("loc_x")
            loc_y = info.getInteger("loc_y")
            loc_z = info.getInteger("loc_z")
            heading = info.getInteger("heading")
            hp = info.getInteger("currentHP")
            mp = info.getInteger("currentMP")
            zaken = self.addSpawn(ZAKEN,loc_x,loc_y,loc_z,heading,False,0)
            GrandBossManager.getInstance().addBoss(zaken)
            zaken.setCurrentHpMp(hp,mp)

    def onAdvEvent (self,event,npc,player):
        if event == "zaken_respawn" :
            zaken = self.addSpawn(ZAKEN,55312,219168,-3223,0,False,0)
            GrandBossManager.getInstance().setBossStatus(ZAKEN,ALIVE)
            GrandBossManager.getInstance().addBoss(zaken)
        return

    def onKill(self,npc,player,isPet):
        GrandBossManager.getInstance().setBossStatus(ZAKEN,DEAD)
        respawnTime = long((19 + Rnd.get(35)) * 3600000)
        self.startQuestTimer("zaken_respawn", respawnTime, None, None)
        # also save the respawn time so that the info is maintained past reboots
        info = GrandBossManager.getInstance().getStatsSet(ZAKEN)
        info.set("respawn_time",(long(System.currentTimeMillis()) + respawnTime))
        GrandBossManager.getInstance().setStatsSet(ZAKEN,info)
        return 

# now call the constructor (starts up the ai)
QUEST		= Zaken(-1,"zaken","ai")

QUEST.addKillId(ZAKEN)